@@ -7,6 +7,7 @@ from lightwood.helpers.log import log
 from lightwood.helpers.numeric import can_be_nan_numeric
 from lightwood.mixer.base import BaseMixer
 from lightwood.ensemble.base import BaseEnsemble
+from lightwood.api.types import PredictionArguments
 from lightwood.data.encoded_ds import EncodedDs
 from lightwood.helpers.general import evaluate_accuracy
 
@@ -15,14 +16,14 @@ class BestOf(BaseEnsemble):
     indexes_by_accuracy: List[float]
 
     def __init__(self, target, mixers: List[BaseMixer], data: EncodedDs, accuracy_functions,
-                 ts_analysis: Optional[dict] = None) -> None:
+                 args: PredictionArguments, ts_analysis: Optional[dict] = None) -> None:
         super().__init__(target, mixers, data)
 
         score_list = []
         for _, mixer in enumerate(mixers):
             score_dict = evaluate_accuracy(
                 data.data_frame,
-                mixer(data)['prediction'],
+                mixer(data, args)['prediction'],
                 target,
                 accuracy_functions,
                 ts_analysis=ts_analysis
@@ -40,13 +41,22 @@ class BestOf(BaseEnsemble):
         self.supports_proba = self.mixers[self.indexes_by_accuracy[0]].supports_proba
         log.info(f'Picked best mixer: {type(self.mixers[self.indexes_by_accuracy[0]]).__name__}')
 
-    def __call__(self, ds: EncodedDs, predict_proba: bool = False) -> pd.DataFrame:
-        for mixer_index in self.indexes_by_accuracy:
-            try:
-                return self.mixers[mixer_index](ds, predict_proba=predict_proba)
-            except Exception as e:
-                if self.mixers[mixer_index].stable:
-                    raise(e)
-                else:
-                    log.warning(f'Unstable mixer {type(self.mixers[mixer_index]).__name__} failed with exception: {e}.\
-                    Trying next best')
+    def __call__(self, ds: EncodedDs, args: PredictionArguments) -> pd.DataFrame:
+        if args.all_mixers:
+            all_predictions = [self.mixers[index](ds, args=args) for index in range(len(self.mixers))]
+            for index, predictions in enumerate(all_predictions):
+                all_predictions[index]['__mdb_mixer'] = index
+                all_predictions[index]['__mdb_best_mixer'] = index == self.best_index
+            return pd.concat(all_predictions)
+
+        else:
+            for mixer_index in self.indexes_by_accuracy:
+                mixer = self.mixers[mixer_index]
+                try:
+                    return mixer(ds, args=args)
+                except Exception as e:
+                    if mixer.stable:
+                        raise(e)
+                    else:
+                        log.warning(f'Unstable mixer {type(mixer).__name__} failed with exception: {e}.\
+                        Trying next best')
