@@ -15,14 +15,14 @@ from torch.optim.optimizer import Optimizer
 
 from lightwood.api import dtype
 from lightwood.helpers.log import log
-from lightwood.api.types import TimeseriesSettings
+from lightwood.encoder.base import BaseEncoder
 from lightwood.helpers.torch import LightwoodAutocast
 from lightwood.data.encoded_ds import EncodedDs
-from lightwood.mixer.helpers.transform_corss_entropy_loss import TransformCrossEntropyLoss
 from lightwood.mixer.base import BaseMixer
 from lightwood.mixer.helpers.ar_net import ArNet
 from lightwood.mixer.helpers.default_net import DefaultNet
-from lightwood.encoder.base import BaseEncoder
+from lightwood.api.types import TimeseriesSettings, PredictionArguments
+from lightwood.mixer.helpers.transform_corss_entropy_loss import TransformCrossEntropyLoss
 
 
 class Neural(BaseMixer):
@@ -276,7 +276,8 @@ class Neural(BaseMixer):
         self.model, _, _ = self._max_fit(train_dl, dev_dl, criterion, optimizer, scaler,
                                          self.stop_after, max(1, int(self.epochs_to_best / 3)))
 
-    def __call__(self, ds: EncodedDs, predict_proba: bool = False) -> pd.DataFrame:
+    def __call__(self, ds: EncodedDs,
+                 args: PredictionArguments = PredictionArguments()) -> pd.DataFrame:
         self.model = self.model.eval()
         decoded_predictions: List[object] = []
         all_probs: List[List[float]] = []
@@ -292,7 +293,7 @@ class Neural(BaseMixer):
                 for dep in self.target_encoder.dependencies:
                     kwargs['dependency_data'] = {dep: ds.data_frame.iloc[idx][[dep]].values}
 
-                if predict_proba and self.supports_proba:
+                if args.predict_proba and self.supports_proba:
                     kwargs['return_raw'] = True
                     decoded_prediction, probs, rev_map = self.target_encoder.decode(Yh, **kwargs)
                     all_probs.append(probs)
@@ -306,7 +307,7 @@ class Neural(BaseMixer):
 
             ydf = pd.DataFrame({'prediction': decoded_predictions})
 
-            if predict_proba and self.supports_proba:
+            if args.predict_proba and self.supports_proba:
                 raw_predictions = np.array(all_probs).squeeze()
                 for idx, label in enumerate(rev_map.values()):
                     ydf[f'__mdb_proba_{label}'] = raw_predictions[:, idx]
